==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/fa.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'fa', {
	acccessKey: 'کلید دستیابی',
	advanced: 'پیشرفته',
	advisoryContentType: 'نوع محتوای کمکی',
	advisoryTitle: 'عنوان کمکی',
	anchor: {
		toolbar: 'گنجاندن/ویرایش لنگر',
		menu: 'ویژگی​های لنگر',
		title: 'ویژگی​های لنگر',
		name: 'نام لنگر',
		errorName: 'لطفا نام لنگر را بنویسید',
		remove: 'حذف لنگر'
	},
	anchorId: 'با شناسهٴ المان',
	anchorName: 'با نام لنگر',
	charset: 'نویسه​گان منبع پیوند شده',
	cssClasses: 'کلاس​های شیوه​نامه(Stylesheet)',
	emailAddress: 'نشانی پست الکترونیکی',
	emailBody: 'متن پیام',
	emailSubject: 'موضوع پیام',
	id: 'شناسه',
	info: 'اطلاعات پیوند',
	langCode: 'جهت​نمای زبان',
	langDir: 'جهت​نمای زبان',
	langDirLTR: 'چپ به راست (LTR)',
	langDirRTL: 'راست به چپ (RTL)',
	menu: 'ویرایش پیوند',
	name: 'نام',
	noAnchors: '(در این سند لنگری دردسترس نیست)',
	noEmail: 'لطفا نشانی پست الکترونیکی را بنویسید',
	noUrl: 'لطفا URL پیوند را بنویسید',
	other: '<سایر>',
	popupDependent: 'وابسته (Netscape)',
	popupFeatures: 'ویژگی​های پنجرهٴ پاپاپ',
	popupFullScreen: 'تمام صفحه (IE)',
	popupLeft: 'موقعیت چپ',
	popupLocationBar: 'نوار موقعیت',
	popupMenuBar: 'نوار منو',
	popupResizable: 'قابل تغییر اندازه',
	popupScrollBars: 'میله​های پیمایش',
	popupStatusBar: 'نوار وضعیت',
	popupToolbar: 'نوار ابزار',
	popupTop: 'موقعیت بالا',
	rel: 'وابستگی',
	selectAnchor: 'یک لنگر برگزینید',
	styles: 'شیوه (style)',
	tabIndex: 'نمایهٴ دسترسی با برگه',
	target: 'مقصد',
	targetFrame: '<فریم>',
	targetFrameName: 'نام فریم مقصد',
	targetPopup: '<پنجرهٴ پاپاپ>',
	targetPopupName: 'نام پنجرهٴ پاپاپ',
	title: 'پیوند',
	toAnchor: 'لنگر در همین صفحه',
	toEmail: 'پست الکترونیکی',
	toUrl: 'URL',
	toolbar: 'گنجاندن/ویرایش پیوند',
	type: 'نوع پیوند',
	unlink: 'برداشتن پیوند',
	upload: 'انتقال به سرور'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/fa.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'fa', {
	acccessKey: 'کلید دستیابی',
	advanced: 'پیشرفته',
	advisoryContentType: 'نوع محتوای کمکی',
	advisoryTitle: 'عنوان کمکی',
	anchor: {
		toolbar: 'گنجاندن/ویرایش لنگر',
		menu: 'ویژگی​های لنگر',
		title: 'ویژگی​های لنگر',
		name: 'نام لنگر',
		errorName: 'لطفا نام لنگر را بنویسید',
		remove: 'حذف لنگر'
	},
	anchorId: 'با شناسهٴ المان',
	anchorName: 'با نام لنگر',
	charset: 'نویسه​گان منبع پیوند شده',
	cssClasses: 'کلاس​های شیوه​نامه(Stylesheet)',
	download: 'Force Download', // MISSING
	displayText: 'نمایش متن',
	emailAddress: 'نشانی پست الکترونیکی',
	emailBody: 'متن پیام',
	emailSubject: 'موضوع پیام',
	id: 'شناسه',
	info: 'اطلاعات پیوند',
	langCode: 'جهت​نمای زبان',
	langDir: 'جهت​نمای زبان',
	langDirLTR: 'چپ به راست (LTR)',
	langDirRTL: 'راست به چپ (RTL)',
	menu: 'ویرایش پیوند',
	name: 'نام',
	noAnchors: '(در این سند لنگری دردسترس نیست)',
	noEmail: 'لطفا نشانی پست الکترونیکی را بنویسید',
	noUrl: 'لطفا URL پیوند را بنویسید',
	noTel: 'Please type the phone number', // MISSING
	other: '<سایر>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'وابسته (Netscape)',
	popupFeatures: 'ویژگی​های پنجرهٴ پاپاپ',
	popupFullScreen: 'تمام صفحه (IE)',
	popupLeft: 'موقعیت چپ',
	popupLocationBar: 'نوار موقعیت',
	popupMenuBar: 'نوار منو',
	popupResizable: 'قابل تغییر اندازه',
	popupScrollBars: 'میله​های پیمایش',
	popupStatusBar: 'نوار وضعیت',
	popupToolbar: 'نوار ابزار',
	popupTop: 'موقعیت بالا',
	rel: 'وابستگی',
	selectAnchor: 'یک لنگر برگزینید',
	styles: 'شیوه (style)',
	tabIndex: 'نمایهٴ دسترسی با برگه',
	target: 'مقصد',
	targetFrame: '<فریم>',
	targetFrameName: 'نام فریم مقصد',
	targetPopup: '<پنجرهٴ پاپاپ>',
	targetPopupName: 'نام پنجرهٴ پاپاپ',
	title: 'پیوند',
	toAnchor: 'لنگر در همین صفحه',
	toEmail: 'پست الکترونیکی',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'گنجاندن/ویرایش پیوند',
	type: 'نوع پیوند',
	unlink: 'برداشتن پیوند',
	upload: 'انتقال به سرور'
} );
